@@ -1,11 +1,10 @@
 # @package      hubzero-use
 # @file         environ.sh
 # @author       Rick Kennell <kennell@purdue.edu>
-# @copyright    Copyright (c) 2006-2010 Purdue University. All rights reserved.
+# @copyright    Copyright (c) 2006-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2006-2010 Purdue University
-# All rights reserved.
+# Copyright (c) 2006-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -14,7 +13,7 @@
 # the GNU Lesser General Public License as published by the Free Software
 # Foundation, either version 3 of the License, or (at your option) any
 # later version.
-#
+#cd /
 # HUBzero is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -23,7 +22,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
 # To adjust software environments...
@@ -36,9 +35,14 @@ unuse ()
   eval `/etc/environ sh unuse $*`
 }
 
-if [ "$ENVIRON_CONFIG_DIRS" == "" ]
-then
-	ENVIRON_CONFIG_DIRS="/etc/environ.d"
+ENVIRON_CONFIG_DIRS="/etc/environ.d"
+export ENVIRON_CONFIG_DIRS
 
-	export ENVIRON_CONFIG_DIRS
+if [ -d /etc/environ.conf.d ]; then
+  for i in /etc/environ.conf.d/*.sh; do
+    if [ -r $i ]; then
+      . $i
+    fi
+  done
+  unset i
 fi
