@@ -2,11 +2,10 @@
 # @file         use.sh
 # @author       Rick Kennell <kennell@purdue.edu>
 # @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
-# @copyright    Copyright (c) 2006-2011 Purdue University. All rights reserved.
+# @copyright    Copyright (c) 2006-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2006-2011 Purdue University
-# All rights reserved.
+# Copyright (c) 2006-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -24,13 +23,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
 . /etc/environ.sh
 
-ENVIRON_CONFIG_DIRS="${ENVIRON_CONFIG_DIRS} ${HOME}/.environ.d"
-
+ENVIRON_CONFIG_DIRS="${HOME}/.environ.d ${ENVIRON_CONFIG_DIRS}"
 export ENVIRON_CONFIG_DIRS
 
 if [ -e ${HOME}/.environ ]
